@@ -1,7 +1,7 @@
 use crate::{
   check_community_or_site_ban,
   check_is_apub_id_valid,
-  fetcher::{community::get_or_fetch_and_upsert_community, person::get_or_fetch_and_upsert_person},
+  fetcher::object_id::ObjectId,
   generate_moderators_url,
 };
 use anyhow::anyhow;
@@ -39,11 +39,11 @@ pub enum CreateOrUpdateType {
 /// Checks that the specified Url actually identifies a Person (by fetching it), and that the person
 /// doesn't have a site ban.
 async fn verify_person(
-  person_id: &Url,
+  person_id: &ObjectId<Person>,
   context: &LemmyContext,
   request_counter: &mut i32,
 ) -> Result<(), LemmyError> {
-  let person = get_or_fetch_and_upsert_person(person_id, context, request_counter).await?;
+  let person = person_id.dereference(context, request_counter).await?;
   if person.banned {
     return Err(anyhow!("Person {} is banned", person_id).into());
   }
@@ -58,7 +58,8 @@ pub(crate) async fn extract_community(
   let mut cc_iter = cc.iter();
   loop {
     if let Some(cid) = cc_iter.next() {
-      if let Ok(c) = get_or_fetch_and_upsert_community(cid, context, request_counter).await {
+      let cid = ObjectId::new(cid.clone());
+      if let Ok(c) = cid.dereference(context, request_counter).await {
         break Ok(c);
       }
     } else {
@@ -70,28 +71,28 @@ pub(crate) async fn extract_community(
 /// Fetches the person and community to verify their type, then checks if person is banned from site
 /// or community.
 pub(crate) async fn verify_person_in_community(
-  person_id: &Url,
-  community_id: &Url,
+  person_id: &ObjectId<Person>,
+  community_id: &ObjectId<Community>,
   context: &LemmyContext,
   request_counter: &mut i32,
 ) -> Result<(), LemmyError> {
-  let community = get_or_fetch_and_upsert_community(community_id, context, request_counter).await?;
-  let person = get_or_fetch_and_upsert_person(person_id, context, request_counter).await?;
+  let community = community_id.dereference(context, request_counter).await?;
+  let person = person_id.dereference(context, request_counter).await?;
   check_community_or_site_ban(&person, community.id, context.pool()).await
 }
 
 /// Simply check that the url actually refers to a valid group.
 async fn verify_community(
-  community_id: &Url,
+  community_id: &ObjectId<Community>,
   context: &LemmyContext,
   request_counter: &mut i32,
 ) -> Result<(), LemmyError> {
-  get_or_fetch_and_upsert_community(community_id, context, request_counter).await?;
+  community_id.dereference(context, request_counter).await?;
   Ok(())
 }
 
-fn verify_activity(activity: &dyn ActivityFields) -> Result<(), LemmyError> {
-  check_is_apub_id_valid(activity.actor(), false)?;
+fn verify_activity(activity: &dyn ActivityFields, settings: &Settings) -> Result<(), LemmyError> {
+  check_is_apub_id_valid(activity.actor(), false, settings)?;
   verify_domains_match(activity.id_unchecked(), activity.actor())?;
   Ok(())
 }
@@ -100,12 +101,12 @@ fn verify_activity(activity: &dyn ActivityFields) -> Result<(), LemmyError> {
 /// because in case of remote communities, admins can also perform mod actions. As admin status
 /// is not federated, we cant verify their actions remotely.
 pub(crate) async fn verify_mod_action(
-  actor_id: &Url,
-  community: Url,
+  actor_id: &ObjectId<Person>,
+  community_id: ObjectId<Community>,
   context: &LemmyContext,
 ) -> Result<(), LemmyError> {
   let community = blocking(context.pool(), move |conn| {
-    Community::read_from_apub_id(conn, &community.into())
+    Community::read_from_apub_id(conn, &community_id.into())
   })
   .await??;
 
@@ -133,8 +134,11 @@ pub(crate) async fn verify_mod_action(
 
 /// For Add/Remove community moderator activities, check that the target field actually contains
 /// /c/community/moderators. Any different values are unsupported.
-fn verify_add_remove_moderator_target(target: &Url, community: Url) -> Result<(), LemmyError> {
-  if target != &generate_moderators_url(&community.into())?.into_inner() {
+fn verify_add_remove_moderator_target(
+  target: &Url,
+  community: &ObjectId<Community>,
+) -> Result<(), LemmyError> {
+  if target != &generate_moderators_url(&community.clone().into())?.into_inner() {
     return Err(anyhow!("Unkown target url").into());
   }
   Ok(())
@@ -142,13 +146,13 @@ fn verify_add_remove_moderator_target(target: &Url, community: Url) -> Result<()
 
 /// Generate a unique ID for an activity, in the format:
 /// `http(s)://example.com/receive/create/202daf0a-1489-45df-8d2e-c8a3173fed36`
-fn generate_activity_id<T>(kind: T) -> Result<Url, ParseError>
+fn generate_activity_id<T>(kind: T, protocol_and_hostname: &str) -> Result<Url, ParseError>
 where
   T: ToString,
 {
   let id = format!(
     "{}/activities/{}/{}",
-    Settings::get().get_protocol_and_hostname(),
+    protocol_and_hostname,
     kind.to_string().to_lowercase(),
     Uuid::new_v4()
   );
