@@ -181,10 +181,14 @@ impl FromApub for Community {
     let form = Group::from_apub_to_form(group, expected_domain, &context.settings()).await?;
 
     let community = blocking(context.pool(), move |conn| Community::upsert(conn, &form)).await??;
-    update_community_mods(group, &community, context, request_counter).await?;
+    update_community_mods(group, &community, context, request_counter)
+      .await
+      .ok();
 
     // TODO: doing this unconditionally might cause infinite loop for some reason
-    fetch_community_outbox(context, &group.outbox, request_counter).await?;
+    fetch_community_outbox(context, &group.outbox, request_counter)
+      .await
+      .ok();
 
     Ok(community)
   }
